@@ -1,12 +1,12 @@
 import atexit
+import sys
+import threading
+import uuid
 from collections import OrderedDict
 from datetime import datetime
 from functools import reduce
 from operator import itemgetter
-import sys
-import threading
-from typing import Any, Dict, Iterable, Optional, Type, TYPE_CHECKING
-import uuid
+from typing import TYPE_CHECKING, Any, Dict, Iterable, Optional, Type
 
 from pytz import utc
 
@@ -17,7 +17,6 @@ from wsgi_lineprof.stats import FilterType, LineProfilerStats
 from wsgi_lineprof.types import CodeTiming, Measurement, RequestMeasurement, Stream
 from wsgi_lineprof.writers import AsyncStreamWriter, BaseStreamWriter, SyncStreamWriter
 
-
 if TYPE_CHECKING:
     from wsgiref.types import StartResponse, WSGIApplication, WSGIEnvironment
 
@@ -104,7 +103,7 @@ class LineProfilerMiddleware:
         relative_start = profiler.get_timer()
         try:
             profiler.enable()
-            response = self.app(env, start_response)
+            response: Iterable[bytes] = self.app(env, start_response)
         finally:
             profiler.disable()
             unit = profiler.get_unit()
